@@ -15,7 +15,7 @@ with 'WWW::FBX::Role::Auth';
  
 use namespace::autoclean;
 
-our $VERSION = "0.13";
+our $VERSION = "0.14";
 
 has base_url    => ( isa => 'Str', is => 'ro', default => 'http://mafreebox.free.fr' );
 has lwp_args    => ( isa => 'HashRef', is => 'ro', default => sub { {} } );
@@ -184,7 +184,7 @@ Authentication is provided through the Auth role but other authentication mechan
         $res = $fbx->connection;
         print "Your ", $res->{media}, " internet connection state is ", $res->{state}, "\n";
         $fbx->set_ftp_config( {enabled => \1} );
-        $fbx->reset_freeplug( {suff=>"F4:CA:E5:DE:AD:BE/reset/"} );
+        $fbx->reset_freeplug( "F4:CA:E5:DE:AD:BE/reset/" );
     };
 
     if ( my $err = $@ ) {
